==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/hu_HU.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "A tároló elérhetetlen.",
    "Storage invalid" : "A tároló érvénytelen",
    "Unknown error" : "Ismeretlen hiba",
    "Could not move %s - File with this name already exists" : "%s áthelyezése nem sikerült - már létezik másik fájl ezzel a névvel",
    "Could not move %s" : "Nem sikerült %s áthelyezése",
    "Permission denied" : "Engedély megtagadva ",
    "The target folder has been moved or deleted." : "A célmappa törlődött, vagy áthelyezésre került.",
    "The name %s is already used in the folder %s. Please choose a different name." : "A %s név már létezik a %s mappában. Kérem válasszon másik nevet!",
    "Error when creating the file" : "Hiba történt az állomány létrehozásakor",
    "Error when creating the folder" : "Hiba történt a mappa létrehozásakor",
    "Unable to set upload directory." : "Nem található a mappa, ahova feltölteni szeretne.",
    "Invalid Token" : "Hibás token",
    "No file was uploaded. Unknown error" : "Nem történt feltöltés. Ismeretlen hiba",
    "There is no error, the file uploaded with success" : "A fájlt sikerült feltölteni",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "A feltöltött fájl mérete meghaladja a php.ini állományban megadott upload_max_filesize paraméter értékét.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl mérete meghaladja a MAX_FILE_SIZE paramétert, ami a HTML  formban került megadásra.",
    "The uploaded file was only partially uploaded" : "Az eredeti fájlt csak részben sikerült feltölteni.",
    "No file was uploaded" : "Nem töltődött fel állomány",
    "Missing a temporary folder" : "Hiányzik egy ideiglenes mappa",
    "Failed to write to disk" : "Nem sikerült a lemezre történő írás",
    "Not enough storage available" : "Nincs elég szabad hely.",
    "Upload failed. Could not find uploaded file" : "A feltöltés nem sikerült. Nem található a feltöltendő állomány.",
    "Upload failed. Could not get file info." : "A feltöltés nem sikerült. Az állományt leíró információk nem érhetők el.",
    "Invalid directory." : "Érvénytelen mappa.",
    "Files" : "Fájlkezelő",
    "All files" : "Az összes állomány",
    "Favorites" : "Kedvencek",
    "Home" : "Otthoni",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} állomány nem tölthető fel, mert ez vagy egy mappa, vagy pedig 0 bájtból áll.",
    "Total file size {size1} exceeds upload limit {size2}" : "A teljes fájlméret: {size1} meghaladja a feltöltési limitet: {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
    "Upload cancelled." : "A feltöltést megszakítottuk.",
    "Could not get result from server." : "A kiszolgálótól nem kapható meg a művelet eredménye.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fájlfeltöltés van folyamatban. Az oldal elhagyása megszakítja a feltöltést.",
    "{new_name} already exists" : "{new_name} már létezik",
    "Could not create file" : "Az állomány nem hozható létre",
    "Could not create folder" : "A mappa nem hozható létre",
    "Rename" : "Átnevezés",
    "Delete" : "Törlés",
    "Disconnect storage" : "Tároló leválasztása",
    "Unshare" : "A megosztás visszavonása",
    "Download" : "Letöltés",
    "Select" : "Kiválaszt",
    "Pending" : "Folyamatban",
    "Unable to determine date" : "Nem lehet meghatározni a dátumot",
    "Error moving file." : "Hiba történt a fájl áthelyezése közben.",
    "Error moving file" : "Az állomány áthelyezése nem sikerült.",
    "Error" : "Hiba",
    "Could not rename file" : "Az állomány nem nevezhető át",
    "Error deleting file." : "Hiba a file törlése közben.",
    "No entries in this folder match '{filter}'" : "Nincsenek egyező bejegyzések ebben a könyvtárban '{filter}'",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n file_::_%n files_" : ["%n állomány","%n állomány"],
    "You don’t have permission to upload or create files here" : "Önnek nincs jogosultsága ahhoz, hogy ide állományokat töltsön föl, vagy itt újakat hozzon létre",
    "_Uploading %n file_::_Uploading %n files_" : ["%n állomány feltöltése","%n állomány feltöltése"],
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "Your storage is full, files can not be updated or synced anymore!" : "A tároló tele van, a fájlok nem frissíthetőek vagy szinkronizálhatóak a jövőben.",
    "Your storage is almost full ({usedSpacePercent}%)" : "A tároló majdnem tele van ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["egyezések '{filter}'","egyezés '{filter}'"],
    "{dirs} and {files}" : "{dirs} és {files}",
    "Favorited" : "Kedvenc",
    "Favorite" : "Kedvenc",
    "An error occurred while trying to update the tags" : "Hiba történt, miközben megpróbálta frissíteni a címkéket",
    "A new file or folder has been <strong>created</strong>" : "Új fájl vagy könyvtár <strong>létrehozása</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fájl vagy könyvtár <strong>módosítása</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fájl vagy könyvtár <strong>törlése</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fájl vagy könyvtár <strong>visszatöltése</strong>",
    "You created %1$s" : "Létrehoztam: %1$s",
    "%2$s created %1$s" : "%2$s létrehozta: %1$s",
    "%1$s was created in a public folder" : "Nyilvános mappában hozták létre: %1$s",
    "You changed %1$s" : "Megváltoztattam: %1$s",
    "%2$s changed %1$s" : "%2$s megváltoztatta: %1$s",
    "You deleted %1$s" : "Töröltem: %1$s",
    "%2$s deleted %1$s" : "%2$s törölte: %1$s",
    "You restored %1$s" : "Visszatöltötted %1$s",
    "%2$s restored %1$s" : "%1$s visszatöltötte %2$s",
    "%s could not be renamed as it has been deleted" : "%s nem lehet átnevezni, mivel törölve lett",
    "%s could not be renamed" : "%s átnevezése nem sikerült",
    "Upload (max. %s)" : "Feltöltés (max. %s)",
    "File handling" : "Fájlkezelés",
    "Maximum upload size" : "Maximális feltölthető fájlméret",
    "max. possible: " : "max. lehetséges: ",
    "Save" : "Mentés",
    "Can not be edited from here due to insufficient permissions." : "Innen nem lehet szerkeszteni az elégtelen jogosultság miatt ",
    "Settings" : "Beállítások",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Ezt a címet használja, ha <a href=\"%s\" target=\"_blank\">WebDAV-on keresztül szeretné elérni a fájljait</a>",
    "New" : "Új",
    "New text file" : "Új szövegfájl",
    "Text file" : "Szövegfájl",
    "New folder" : "Új mappa",
    "Folder" : "Mappa",
    "Upload" : "Feltöltés",
    "Cancel upload" : "A feltöltés megszakítása",
    "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Select all" : "Összes kijelölése",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltöltendő állományok mérete meghaladja a kiszolgálón megengedett maximális méretet.",
    "Files are being scanned, please wait." : "A fájllista ellenőrzése zajlik, kis türelmet!",
    "Currently scanning" : "Mappaellenőrzés: ",
    "No favorites" : "Nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találod meg"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/hu_HU.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "A tároló elérhetetlen.",
    "Storage invalid" : "A tároló érvénytelen",
    "Unknown error" : "Ismeretlen hiba",
    "Unable to set upload directory." : "Nem található a mappa, ahova feltölteni szeretne.",
    "Invalid Token" : "Hibás token",
    "No file was uploaded. Unknown error" : "Nem történt feltöltés. Ismeretlen hiba",
    "There is no error, the file uploaded with success" : "A fájlt sikerült feltölteni",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "A feltöltött fájl mérete meghaladja a php.ini állományban megadott upload_max_filesize paraméter értékét.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl mérete meghaladja a MAX_FILE_SIZE paramétert, ami a HTML  formban került megadásra.",
    "The uploaded file was only partially uploaded" : "Az eredeti fájlt csak részben sikerült feltölteni.",
    "No file was uploaded" : "Nem töltődött fel állomány",
    "Missing a temporary folder" : "Hiányzik egy ideiglenes mappa",
    "Failed to write to disk" : "Nem sikerült a lemezre történő írás",
    "Not enough storage available" : "Nincs elég szabad hely.",
    "The target folder has been moved or deleted." : "A célmappa törlődött, vagy áthelyezésre került.",
    "Upload failed. Could not find uploaded file" : "A feltöltés nem sikerült. Nem található a feltöltendő állomány.",
    "Upload failed. Could not get file info." : "A feltöltés nem sikerült. Az állományt leíró információk nem érhetők el.",
    "Invalid directory." : "Érvénytelen mappa.",
    "Files" : "Fájlkezelő",
    "All files" : "Az összes állomány",
    "Favorites" : "Kedvencek",
    "Home" : "Otthoni",
    "Close" : "Bezárás",
    "Upload cancelled." : "A feltöltést megszakítottuk.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "A(z) {filename} állomány nem tölthető fel, mert ez vagy egy mappa, vagy pedig 0 bájtból áll.",
    "Total file size {size1} exceeds upload limit {size2}" : "A teljes fájlméret: {size1} meghaladja a feltöltési limitet: {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nincs elég szabad hely. A feltöltés mérete {size1}, de csak ennyi hely van: {size2}.",
    "Could not get result from server." : "A kiszolgálótól nem kapható meg a művelet eredménye.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fájlfeltöltés van folyamatban. Az oldal elhagyása megszakítja a feltöltést.",
    "Actions" : "Műveletek",
    "Download" : "Letöltés",
    "Rename" : "Átnevezés",
    "Delete" : "Törlés",
    "Disconnect storage" : "Tároló leválasztása",
    "Unshare" : "A megosztás visszavonása",
    "Details" : "Részletek",
    "Select" : "Kiválaszt",
    "Pending" : "Folyamatban",
    "Unable to determine date" : "Nem lehet meghatározni a dátumot",
    "This operation is forbidden" : "Tiltott művelet",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem elérhető, kérem nézze meg a naplófájlokat vagy keresse az adminisztrátort",
    "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
    "Could not move \"{file}\"" : "{file} fájl nem áthelyezhető",
    "{newName} already exists" : "{newName} már létezik",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nem átnevezhető erre: {fileName}, mert már nem létezik",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "{targetName} már használatban van a(z) {dir} könyvtárban. Kérjük, válassz másik nevet.",
    "Could not rename \"{fileName}\"" : "{fileName} fájl nem átnevezhető",
    "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
    "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
    "Could not create folder \"{dir}\"" : "{dir} könyvtár nem létrehozható",
    "Could not create folder \"{dir}\" because it already exists" : "{dir} könyvtár nem létrehozható, mert már létezik",
    "Error deleting file \"{fileName}\"." : "Hiba történt {fileName} fájl törlése közben.",
    "No entries in this folder match '{filter}'" : "Nincsenek egyező bejegyzések ebben a könyvtárban '{filter}'",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "_%n folder_::_%n folders_" : ["%n mappa","%n mappa"],
    "_%n file_::_%n files_" : ["%n állomány","%n állomány"],
    "{dirs} and {files}" : "{dirs} és {files}",
    "You don’t have permission to upload or create files here" : "Önnek nincs jogosultsága ahhoz, hogy ide állományokat töltsön föl, vagy itt újakat hozzon létre",
    "_Uploading %n file_::_Uploading %n files_" : ["%n állomány feltöltése","%n állomány feltöltése"],
    "New" : "Új",
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "A {owner} felhasználó tárolója betelt, a fájlok nem frissíthetők és szinkronizálhatók többet!",
    "Your storage is full, files can not be updated or synced anymore!" : "A tároló tele van, a fájlok nem frissíthetőek vagy szinkronizálhatóak a jövőben.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "A {owner} felhasználó tárolója majdnem betelt ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "A tároló majdnem tele van ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["egyezések '{filter}'","egyezés '{filter}'"],
    "Path" : "Útvonal",
    "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
    "Favorited" : "Kedvenc",
    "Favorite" : "Kedvenc",
    "Folder" : "Mappa",
    "New folder" : "Új mappa",
    "{newname} already exists" : "{newname} már létezik",
    "Upload" : "Feltöltés",
    "An error occurred while trying to update the tags" : "Hiba történt, miközben megpróbálta frissíteni a címkéket",
    "A new file or folder has been <strong>created</strong>" : "Új fájl vagy könyvtár <strong>létrehozása</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fájl vagy könyvtár <strong>módosítása</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Szűkítse le az értesítéseket a létrehozásról és a változásokról a <strong>kedvenc fájlok</strong> <em>(Stream only)</em> -ra",
    "A file or folder has been <strong>deleted</strong>" : "Fájl vagy könyvtár <strong>törlése</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fájl vagy könyvtár <strong>visszatöltése</strong>",
    "You created %1$s" : "Létrehoztam: %1$s",
    "%2$s created %1$s" : "%2$s létrehozta: %1$s",
    "%1$s was created in a public folder" : "Nyilvános mappában hozták létre: %1$s",
    "You changed %1$s" : "Megváltoztattam: %1$s",
    "%2$s changed %1$s" : "%2$s megváltoztatta: %1$s",
    "You deleted %1$s" : "Töröltem: %1$s",
    "%2$s deleted %1$s" : "%2$s törölte: %1$s",
    "You restored %1$s" : "Visszatöltötted %1$s",
    "%2$s restored %1$s" : "%1$s visszatöltötte %2$s",
    "Changed by %2$s" : "Megváltoztatta: %2$s",
    "Deleted by %2$s" : "Törölte: %2$s",
    "Restored by %2$s" : "Visszaállította: %2$s",
    "Upload (max. %s)" : "Feltöltés (max.: %s)",
    "File handling" : "Fájlkezelés",
    "Maximum upload size" : "Maximális feltölthető fájlméret",
    "max. possible: " : "max. lehetséges: ",
    "Save" : "Mentés",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-mel akár 5 percbe is telhet, míg ez a beállítás érvénybe lép.",
    "Missing permissions to edit from here." : "Innen nem lehet szerkeszteni hiányzó jogosultság miatt.",
    "Settings" : "Beállítások",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Ezt a címet használja, ha <a href=\"%s\" target=\"_blank\">WebDAV-on keresztül szeretné elérni a fájljait</a>",
    "Cancel upload" : "A feltöltés megszakítása",
    "No files in here" : "Itt nincsenek fájlok",
    "Upload some content or sync with your devices!" : "Tölts fel néhány tartalmat, vagy szinkronizálj az eszközöddel!",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Select all" : "Összes kijelölése",
    "Upload too large" : "A feltöltés túl nagy",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltöltendő állományok mérete meghaladja a kiszolgálón megengedett maximális méretet.",
    "No favorites" : "Nincsenek kedvencek",
    "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találod meg",
    "Text file" : "Szövegfájl",
    "New text file.txt" : "Új szöveges fájl.txt",
    "Changed by %2$s" : "Megváltoztatta: %2$s",
    "Deleted by %2$s" : "Törölte: %2$s",
    "Restored by %2$s" : "Visszaállította: %2$s",
    "You changed %1$s" : "Megváltoztattam: %1$s",
    "You created %1$s" : "Létrehoztam: %1$s",
    "You deleted %1$s" : "Töröltem: %1$s",
    "You restored %1$s" : "Visszatöltötted %1$s"
},
"nplurals=2; plural=(n != 1);");
